@@ -203,6 +203,18 @@ class MyBuddyCommandGenerator(MyCobotCommandGenerator):
         degrees = [self._angle2int(degree) for degree in degrees]
         return self._mesg(ProtocolCode.SEND_ANGLES, id, degrees, speed)
 
+    def send_angles_auto(self, id, degrees, _time):
+        """Send all angles to the robotic arm
+
+        Args:
+            id: 1/2 (L/R).
+            degrees: [angle_list] len 6
+            _time: 1 - 100
+        """
+        # self.calibration_parameters(degrees=degrees, speed=speed)
+        degrees = [self._angle2int(degree) for degree in degrees]
+        return self._mesg(ProtocolCode.SEND_ANGLES_AUTO, id, degrees, _time)
+
     def get_coords(self, id):
         """Get the coordinates of the robotic arm
         
@@ -1062,7 +1074,7 @@ class MyBuddyCommandGenerator(MyCobotCommandGenerator):
         Args:
             state (int): 0 - close 1 - open (Off by default)
         """
-        return self._mesg(ProtocolCode.COLLISION_SWITCH, state)
+        return self._mesg(ProtocolCode.COLLISION_SWITCH, 0, state)
     
     def is_collision_on(self):
         """Get collision detection status
@@ -1072,6 +1084,28 @@ class MyBuddyCommandGenerator(MyCobotCommandGenerator):
             1 - open
         """
         return self._mesg(ProtocolCode.IS_COLLISION_ON, 0, has_reply = True)
+    
+    def get_servo_speeds(self, id):
+        """Get joint speed
+        
+        Args:
+            id: 1/2 (L/R)
+        
+        Return: 
+            unit step/s
+        """
+        return self._mesg(0xE7, id, has_reply=True)
+    
+    def set_encoders_drag(self, id, encoders, speeds):
+        """Send all potential values and speeds
+        
+        Args:
+            id: 1/2 (L/R)
+            encoders: encoder value ,list len 6
+            speeds: from get_servo_speeds()
+        
+        """
+        return self._mesg(ProtocolCode.SET_ENCODERS_DRAG, id, encoders, speeds)
         
     
     # def init_iic(self):
